import { C as CreatePortfolioSettingsRequest$1, c as CreatePortfolioSettingsResponse$1, d as GetPortfolioSettingsRequest$1, G as GetPortfolioSettingsResponse$1, e as UpdatePortfolioSettingsRequest$1, U as UpdatePortfolioSettingsResponse$1 } from './portfolio-portfolio-app-v1-portfolio-settings-portfolio-settings.universal-BgJqvP95.mjs';

interface PortfolioSettings {
    /**
     * Revision number. Increments by 1 each time the portfolio settings object is updated. To prevent conflicting changes, the existing revision must be passed when updating the portfolio settings object.
     * @readonly
     */
    revision?: string | null;
    /** Portfolio's project item settings. */
    projectItemSettings?: ProjectItemSettings;
    /** Portfolio's media settings. */
    mediaSettings?: MediaSettings;
    /**
     * Date and time the portfolio settings were created.
     * @readonly
     */
    createdDate?: Date | null;
    /**
     * Date and time the portfolio settings were updated.
     * @readonly
     */
    updatedDate?: Date | null;
}
interface ProjectItemSettings {
    /** The direction in which to add new project items to a gallery. Default: `GALLERY_START` */
    addItemDirection?: AddItemDirectionWithLiterals;
    /** Default title assigned to a project item if no title is provided. Default: `FILE_NAME` */
    defaultItemName?: DefaultItemNameWithLiterals;
}
declare enum AddItemDirection {
    /** Add new project items to the beginning of the gallery. */
    GALLERY_START = "GALLERY_START",
    /** Add new project items to the end of the gallery. */
    GALLERY_END = "GALLERY_END"
}
/** @enumType */
type AddItemDirectionWithLiterals = AddItemDirection | 'GALLERY_START' | 'GALLERY_END';
declare enum DefaultItemName {
    /** File name assigned as the title. */
    FILE_NAME = "FILE_NAME",
    /** No title assigned. */
    EMPTY = "EMPTY"
}
/** @enumType */
type DefaultItemNameWithLiterals = DefaultItemName | 'FILE_NAME' | 'EMPTY';
interface MediaSettings {
    /** ID of the folder containing the media. */
    folderId?: string | null;
}
interface CreatePortfolioSettingsRequest {
    /** The portfolio settings to create. */
    portfolioSettings: PortfolioSettings;
}
interface CreatePortfolioSettingsResponse {
    /** Newly created portfolio settings. */
    portfolioSettings?: PortfolioSettings;
}
interface GetPortfolioSettingsRequest {
}
interface GetPortfolioSettingsResponse {
    /** Portfolio settings. */
    portfolioSettings?: PortfolioSettings;
}
interface UpdatePortfolioSettingsRequest {
    /** The portfolio settings to update. */
    portfolioSettings: PortfolioSettings;
}
interface UpdatePortfolioSettingsResponse {
    /** Updated portfolio settings. */
    updatedPortfolioSettings?: PortfolioSettings;
}

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function createPortfolioSettings(): __PublicMethodMetaInfo<'POST', {}, CreatePortfolioSettingsRequest$1, CreatePortfolioSettingsRequest, CreatePortfolioSettingsResponse$1, CreatePortfolioSettingsResponse>;
declare function getPortfolioSettings(): __PublicMethodMetaInfo<'GET', {}, GetPortfolioSettingsRequest$1, GetPortfolioSettingsRequest, GetPortfolioSettingsResponse$1, GetPortfolioSettingsResponse>;
declare function updatePortfolioSettings(): __PublicMethodMetaInfo<'PATCH', {}, UpdatePortfolioSettingsRequest$1, UpdatePortfolioSettingsRequest, UpdatePortfolioSettingsResponse$1, UpdatePortfolioSettingsResponse>;

export { type __PublicMethodMetaInfo, createPortfolioSettings, getPortfolioSettings, updatePortfolioSettings };
