interface PortfolioSettings {
    /**
     * Revision number. Increments by 1 each time the portfolio settings object is updated. To prevent conflicting changes, the existing revision must be passed when updating the portfolio settings object.
     * @readonly
     */
    revision?: string | null;
    /** Portfolio's project item settings. */
    projectItemSettings?: ProjectItemSettings;
    /** Portfolio's media settings. */
    mediaSettings?: MediaSettings;
    /**
     * Date and time the portfolio settings were created.
     * @readonly
     */
    _createdDate?: Date | null;
    /**
     * Date and time the portfolio settings were updated.
     * @readonly
     */
    _updatedDate?: Date | null;
}
interface ProjectItemSettings {
    /** The direction in which to add new project items to a gallery. Default: `GALLERY_START` */
    addItemDirection?: AddItemDirectionWithLiterals;
    /** Default title assigned to a project item if no title is provided. Default: `FILE_NAME` */
    defaultItemName?: DefaultItemNameWithLiterals;
}
declare enum AddItemDirection {
    /** Add new project items to the beginning of the gallery. */
    GALLERY_START = "GALLERY_START",
    /** Add new project items to the end of the gallery. */
    GALLERY_END = "GALLERY_END"
}
/** @enumType */
type AddItemDirectionWithLiterals = AddItemDirection | 'GALLERY_START' | 'GALLERY_END';
declare enum DefaultItemName {
    /** File name assigned as the title. */
    FILE_NAME = "FILE_NAME",
    /** No title assigned. */
    EMPTY = "EMPTY"
}
/** @enumType */
type DefaultItemNameWithLiterals = DefaultItemName | 'FILE_NAME' | 'EMPTY';
interface MediaSettings {
    /** ID of the folder containing the media. */
    folderId?: string | null;
}
interface SiteMenuSettings {
    /** Whether to automatically update the site menu */
    autoUpdateMenu?: boolean | null;
}
interface CreatePortfolioSettingsRequest {
    /** The portfolio settings to create. */
    portfolioSettings: PortfolioSettings;
}
interface CreatePortfolioSettingsResponse {
    /** Newly created portfolio settings. */
    portfolioSettings?: PortfolioSettings;
}
interface GetPortfolioSettingsRequest {
}
interface GetPortfolioSettingsResponse {
    /** Portfolio settings. */
    portfolioSettings?: PortfolioSettings;
}
interface UpdatePortfolioSettingsRequest {
    /** The portfolio settings to update. */
    portfolioSettings: PortfolioSettings;
}
interface UpdatePortfolioSettingsResponse {
    /** Updated portfolio settings. */
    updatedPortfolioSettings?: PortfolioSettings;
}
interface DomainEvent extends DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
    /** Event ID. With this ID you can easily spot duplicated events and ignore them. */
    _id?: string;
    /**
     * Fully Qualified Domain Name of an entity. This is a unique identifier assigned to the API main business entities.
     * For example, `wix.stores.catalog.product`, `wix.bookings.session`, `wix.payments.transaction`.
     */
    entityFqdn?: string;
    /**
     * Event action name, placed at the top level to make it easier for users to dispatch messages.
     * For example: `created`/`updated`/`deleted`/`started`/`completed`/`email_opened`.
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example, `2020-04-26T13:57:50.699Z`. */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number that indicates the order of updates to an entity. For example, if an entity was updated at 16:00 and then again at 16:01, the second update will always have a higher sequence number.
     * You can use this number to make sure you're handling updates in the right order. Just save the latest sequence number on your end and compare it to the one in each new message. If the new message has an older (lower) number, you can safely ignore it.
     */
    entityEventSequence?: string | null;
}
/** @oneof */
interface DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
}
interface EntityCreatedEvent {
    entity?: string;
}
interface RestoreInfo {
    deletedDate?: Date | null;
}
interface EntityUpdatedEvent {
    /**
     * Since platformized APIs only expose PATCH and not PUT we can't assume that the fields sent from the client are the actual diff.
     * This means that to generate a list of changed fields (as opposed to sent fields) one needs to traverse both objects.
     * We don't want to impose this on all developers and so we leave this traversal to the notification recipients which need it.
     */
    currentEntity?: string;
}
interface EntityDeletedEvent {
    /** Entity that was deleted. */
    deletedEntity?: string | null;
}
interface ActionEvent {
    body?: string;
}
interface MessageEnvelope {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
    /** Stringify payload. */
    data?: string;
}
interface IdentificationData extends IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
    /** @readonly */
    identityType?: WebhookIdentityTypeWithLiterals;
}
/** @oneof */
interface IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
}
declare enum WebhookIdentityType {
    UNKNOWN = "UNKNOWN",
    ANONYMOUS_VISITOR = "ANONYMOUS_VISITOR",
    MEMBER = "MEMBER",
    WIX_USER = "WIX_USER",
    APP = "APP"
}
/** @enumType */
type WebhookIdentityTypeWithLiterals = WebhookIdentityType | 'UNKNOWN' | 'ANONYMOUS_VISITOR' | 'MEMBER' | 'WIX_USER' | 'APP';
interface BaseEventMetadata {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
}
interface EventMetadata extends BaseEventMetadata {
    /** Event ID. With this ID you can easily spot duplicated events and ignore them. */
    _id?: string;
    /**
     * Fully Qualified Domain Name of an entity. This is a unique identifier assigned to the API main business entities.
     * For example, `wix.stores.catalog.product`, `wix.bookings.session`, `wix.payments.transaction`.
     */
    entityFqdn?: string;
    /**
     * Event action name, placed at the top level to make it easier for users to dispatch messages.
     * For example: `created`/`updated`/`deleted`/`started`/`completed`/`email_opened`.
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example, `2020-04-26T13:57:50.699Z`. */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number that indicates the order of updates to an entity. For example, if an entity was updated at 16:00 and then again at 16:01, the second update will always have a higher sequence number.
     * You can use this number to make sure you're handling updates in the right order. Just save the latest sequence number on your end and compare it to the one in each new message. If the new message has an older (lower) number, you can safely ignore it.
     */
    entityEventSequence?: string | null;
}
interface PortfolioSettingsCreatedEnvelope {
    entity: PortfolioSettings;
    metadata: EventMetadata;
}

export { AddItemDirection as A, type BaseEventMetadata as B, type CreatePortfolioSettingsRequest as C, DefaultItemName as D, type EntityCreatedEvent as E, type GetPortfolioSettingsResponse as G, type IdentificationData as I, type MediaSettings as M, type PortfolioSettings as P, type RestoreInfo as R, type SiteMenuSettings as S, type UpdatePortfolioSettingsResponse as U, WebhookIdentityType as W, type PortfolioSettingsCreatedEnvelope as a, type ProjectItemSettings as b, type CreatePortfolioSettingsResponse as c, type GetPortfolioSettingsRequest as d, type UpdatePortfolioSettingsRequest as e, type DomainEvent as f, type DomainEventBodyOneOf as g, type EntityUpdatedEvent as h, type EntityDeletedEvent as i, type ActionEvent as j, type MessageEnvelope as k, type IdentificationDataIdOneOf as l, type EventMetadata as m };
